aboutsummaryrefslogtreecommitdiff
path: root/doc/modules/skribilo/documentation/manual.scm
diff options
context:
space:
mode:
Diffstat (limited to 'doc/modules/skribilo/documentation/manual.scm')
-rw-r--r--doc/modules/skribilo/documentation/manual.scm34
1 files changed, 17 insertions, 17 deletions
diff --git a/doc/modules/skribilo/documentation/manual.scm b/doc/modules/skribilo/documentation/manual.scm
index f2a6cdd..97501d8 100644
--- a/doc/modules/skribilo/documentation/manual.scm
+++ b/doc/modules/skribilo/documentation/manual.scm
@@ -26,8 +26,8 @@
:use-module (skribilo lib) ;; `define-markup'
:use-module (skribilo resolve)
:use-module (skribilo output)
+ :use-module (skribilo evaluator)
:use-module (skribilo utils keywords)
- :use-module (skribilo utils compat)
:use-module (skribilo utils syntax) ;; `when'
:use-module (skribilo documentation env)
@@ -52,20 +52,20 @@
;*---------------------------------------------------------------------*/
;* Base configuration */
;*---------------------------------------------------------------------*/
-(let ((be (find-engine 'base)))
+(let ((be (lookup-engine-class 'base)))
(markup-writer 'example be
:options '(:legend :number)
:action (lambda (n e)
(let ((ident (markup-ident n))
(number (markup-option n :number))
(legend (markup-option n :legend)))
- (skribe-eval (mark ident) e)
- (skribe-eval (center
- (markup-body n)
- (if number
- (bold (format #f "Ex. ~a: " number)))
- legend)
- e)))))
+ (evaluate-document (mark ident) e)
+ (evaluate-document
+ (center (markup-body n)
+ (if number
+ (bold (format #f "Ex. ~a: " number)))
+ legend)
+ e)))))
;*---------------------------------------------------------------------*/
;* html-browsing-extra ... */
@@ -95,7 +95,7 @@
;*---------------------------------------------------------------------*/
;* Html configuration */
;*---------------------------------------------------------------------*/
-(let* ((he (find-engine 'html))
+(let* ((he (lookup-engine-class 'html))
(bd (markup-writer-get 'bold he)))
(markup-writer 'bold he
:class 'api-proto-ident
@@ -108,7 +108,7 @@
;*---------------------------------------------------------------------*/
;* LaTeX */
;*---------------------------------------------------------------------*/
-(let* ((le (find-engine 'latex))
+(let* ((le (lookup-engine-class 'latex))
(opckg (engine-custom le 'usepackage))
(lpckg "\\usepackage{fullpage}\n\\usepackage{eurosym}\n")
(npckg (if (string? opckg)
@@ -190,7 +190,7 @@
(define-markup (example #!rest opts #!key legend class)
(new container
(markup 'example)
- (ident (symbol->string (gensym 'example)))
+ (ident (symbol->string (gensym "example")))
(class class)
(required-options '(:legend :number))
(options `((:number
@@ -290,19 +290,19 @@
(pref (eq? (engine-custom e 'index-page-ref) #t))
(loc (ast-loc n))
;; FIXME: Since we don't support
;; `:&skribe-eval-location', we could set up a
;; `parameterize' thing around `skribe-eval' to provide
;; it with the right location information.
(t (cond
((null? ie)
"")
((or (not (integer? nc)) (= nc 1))
- (table :width 100. ;;:&skribe-eval-location loc
+ (table :width 100. ;;:&evaluate-document-location loc
(make-column ie pref)))
(else
- (table :width 100. ;;:&skribe-eval-location loc
+ (table :width 100. ;;:&evaluate-document-location loc
(make-sub-tables ie nc pref))))))
- (output (skribe-eval t e) e))))
+ (evaluate-document t e))))
;*---------------------------------------------------------------------*/
;* compiler-command ... */
@@ -290,19 +290,19 @@
(loc (ast-loc n))
;; FIXME: Since we don't support
- ;; `:&skribe-eval-location', we could set up a
- ;; `parameterize' thing around `skribe-eval' to provide
+ ;; `:&evaluate-document-location', we could set up a
+ ;; `parameterize' thing around `evaluate-document' to provide
;; it with the right location information.
(t (cond